@@ -48,4 +48,4 @@
 
 #undef GNOME_ICONDIR
 
-#undef HAVE__ICETRANSNOLISTEN
+#undef DO_LIBICE_CHECK
