@@ -71,6 +71,10 @@ static gboolean
 kill_applet_in_idle(gpointer data)
 {
 	AppletInfo *info = data;
+ 	if (info->type == APPLET_EXTERN) {
+ 		Extern *ext = info->data;
+ 		ext->clean_remove = TRUE;
+ 	}
 	panel_clean_applet(info);
 	return FALSE;
 }
@@ -78,7 +82,7 @@ kill_applet_in_idle(gpointer data)
 static void
 remove_applet_callback(GtkWidget *widget, AppletInfo *info)
 {
-	gtk_idle_add(kill_applet_in_idle, info);
+	gtk_idle_add (kill_applet_in_idle, info);
 }
 
 static void
@@ -557,11 +561,11 @@ applet_button_press (GtkWidget *widget, GdkEventButton *event, AppletInfo *info)
 }
 
 static void
-applet_destroy(GtkWidget *w, AppletInfo *info)
+applet_destroy (GtkWidget *w, AppletInfo *info)
 {
 	GList *li;
 	
-	g_return_if_fail(info != NULL);
+	g_return_if_fail (info != NULL);
 
 	info->widget = NULL;
 
@@ -719,9 +723,9 @@ register_toy(GtkWidget *applet,
 	gtk_widget_dnd_drag_set (GTK_WIDGET(applet), TRUE,
 				 applet_drag_types, 1);*/
 
-	orientation_change(info,panel);
-	size_change(info,panel);
-	back_change(info,panel);
+	orientation_change (info, panel);
+	size_change (info, panel);
+	back_change (info, panel);
 
 	return TRUE;
 }
