@@ -22,14 +22,21 @@ typedef struct {
 } Launcher;
 
 void load_launcher_applet_full(char *params, GnomeDesktopEntry *dentry,
-			       PanelWidget *panel, int pos);
-void load_launcher_applet(char *params, PanelWidget *panel, int pos);
+			       PanelWidget *panel, int pos, gboolean exactpos);
+void load_launcher_applet(char *params, PanelWidget *panel, int pos,
+			  gboolean exactpos);
 void load_launcher_applet_from_info(char *name, char *comment,
 				    char **exec, int execn, char *icon,
-				    PanelWidget *panel, int pos);
+				    PanelWidget *panel, int pos,
+				    gboolean exactpos);
+void load_launcher_applet_from_info_url(char *name, char *comment,
+					char *url, char *icon,
+					PanelWidget *panel, int pos,
+					gboolean exactpos);
 void launcher_properties(Launcher *launcher);
 
-void ask_about_launcher(char *file, PanelWidget *panel, int pos);
+void ask_about_launcher(char *file, PanelWidget *panel, int pos,
+			gboolean exactpos);
 
 END_GNOME_DECLS
 
